Implements SSR by making a POST request to http://{:vite_host}/ssr_render.
ssr_render is implemented as a Vite plugin. Add it to the vite.config.js plugins section:
import liveSveltePlugin from "live_svelte/vitePlugin"
export default {
plugins: [liveSveltePlugin()],
// ...
}Configuration
In config/dev.exs:
config :live_svelte, ssr_module: LiveSvelte.SSR.ViteJS
config :live_svelte, vite_host: "http://localhost:5173"
Summary
Functions
Callback implementation for LiveSvelte.SSR.render/3.
Returns a path relative to the configured Vite JS host.
Functions
Callback implementation for LiveSvelte.SSR.render/3.
Returns a path relative to the configured Vite JS host.